@@ -1,7 +1,7 @@
 import json
 import os
 import yaml
-from typing import Dict, List, Union
+from typing import List, Union
 from bole.consts import CONFIG_SEARCH_PATHS
 from bole.exceptions import BoleException
 from bole.utils import deep_merge
@@ -31,7 +31,9 @@ def config_file_parser(fpath: str, default_format: str = "yaml") -> dict:
     with open(fpath, "r") as config_file:
         config_file_text = config_file.read()
 
-    if format == "yaml":
+    if config_file_text.strip() == "":
+        as_dict = {}
+    elif format == "yaml":
         as_dict = yaml.safe_load(config_file_text)
     elif format == "json":
         as_dict = json.loads(config_file_text)
@@ -110,8 +112,8 @@ class CascadingConfig(CascadingConfigDictionary):
         return CascadingConfigImport.parse_list(self.get(CASCADING_CONFIG_IMPORT_KEY, []))
 
     @property
-    def environments(self) -> Dict[str, "CascadingConfig"]:
-        return CascadingConfig.parse_dictionary(self.get("environments", {}))
+    def environments(self):
+        return self.parse_dictionary(self.get("environments", {}))
 
     @property
     def settings(self) -> CascadingConfigSettings:
@@ -222,7 +224,7 @@ class CascadingConfig(CascadingConfigDictionary):
             config.initialize()
 
             if load_imports:
-                if config.settings.inherit:
+                if config.settings.allow_imports:
                     # if the config has imports they should come before it.
                     configs += cls.__load_siblings(
                         imports=config.config_imports,
